@@ -559,13 +559,13 @@ class DynamicFilterBackend(BaseFilterBackend):
         ):
             id_fields = getattr(serializer, 'get_id_fields', lambda: [])()
             # only include local model fields
-            only = [
-                field for field in set(
-                    id_fields + list(requirements.keys())
-                ) if is_model_field(model, field) and
-                not is_field_remote(model, field)
-            ]
-            queryset = queryset.only(*only)
+#             only = [
+#                 field for field in set(
+#                     id_fields + list(requirements.keys())
+#                 ) if is_model_field(model, field) and
+#                 not is_field_remote(model, field)
+#             ]
+#             queryset = queryset.only(*only)
 
         # add request filters
         query = self._filters_to_query(
