@@ -24,7 +24,7 @@ from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
 from rest_framework.exceptions import ValidationError
 from rest_framework.validators import UniqueValidator
-from dynamic_rest.serializers import DynamicRelationField
+from xtrm_drest.serializers import DynamicRelationField
 
 
 class BaseNestedModelSerializer(serializers.ModelSerializer):
