@@ -205,7 +205,7 @@ class WithDynamicSerializerMixin(
             sideloading=None,
             debug=False,
             dynamic=True,
-            embed=False,
+            embed=True,
             envelope=False,
             **kwargs
     ):
